@@ -35,7 +35,7 @@ class WeatherChart:
 
 		return forecast
 
-	def get_forecast_chart_image_by_loc( self, loc_string , output_file):
+	def get_forecast_chart_image_by_loc( self, loc_string , output_file=None):
 		geolocator = Nominatim(user_agent="pubs_01")
 		location = geolocator.geocode( loc_string )
 		if location: return self.get_forecast_chart_image( location.latitude, location.longitude, output_file )
@@ -43,7 +43,7 @@ class WeatherChart:
 		return None
 
 
-	def get_forecast_chart_image( self, lat, long , output_file):
+	def get_forecast_chart_image( self, lat, long , output_file=None):
 		qc = QuickChart() 
 		qc.width = 500 #set width and height of chart in pixels
 		qc.width = 500
@@ -58,8 +58,9 @@ class WeatherChart:
 			weather_readings.append( forecast[ item_key ]['temp'] )
 		
 		qc.config = self._get_forecast_chart_image_config( labels, weather_readings)
-		print( qc.get_short_url() ) 	#Print out the chart URL
-		qc.to_file( output_file )	#Save to a file
+		# print( ) 	#Print out the chart URL
+		if output_file: qc.to_file( output_file )	#Save to a file
+		return qc.get_short_url() 
 	
 	def _get_forecast_chart_image_config(self, labels, weather_readings ):
 		min, max = self._get_min_max_tick_item( weather_readings, 2)
